@@ -17,14 +17,12 @@ import urllib.parse
 
 import tornado.web
 from bson import ObjectId
-from utils import AioRedis
 from utils import awaitable
 from utils import cached_property
 from utils import Dict
 from utils import JSONEncoder
 from utils import Mongo
 from utils import Motor
-from utils import Redis
 
 
 class BaseHandler(tornado.web.RequestHandler):
@@ -85,15 +83,10 @@ class BaseHandler(tornado.web.RequestHandler):
 
     async def get_current_user(self):
         token = self.get_cookie('token', self.args.token)
-        if token:
-            if hasattr(self.app, 'rd') and isinstance(self.app.rd, (Redis, AioRedis)):
-                user = await awaitable(self.app.rd.get(f'{self.prefix}_token_{token}'))
-                if user:
-                    return Dict(json.loads(user))
-            if hasattr(self.app, 'db') and isinstance(self.app.db, (Mongo, Motor)):
-                user = await awaitable(self.app.db.users.find_one({'token': token}))
-                if user:
-                    return user
+        if token and hasattr(self.app, 'db') and isinstance(self.app.db, (Mongo, Motor)):
+            user = await awaitable(self.app.db.users.find_one({'token': token}))
+            if user:
+                return user
         return Dict()
 
     async def prepare(self):
@@ -169,6 +162,14 @@ class BaseHandler(tornado.web.RequestHandler):
         self.args = Dict(kwargs)
         return Dict(kwargs)
 
+    def add_args(self, **kwargs):
+        ret = urllib.parse.urlparse(self.request.uri)
+        query = urllib.parse.parse_qs(ret.query)
+        query.update(kwargs)
+        uri = urllib.parse.urlunparse((ret.scheme, ret.netloc, ret.path, ret.params,
+                                       urllib.parse.urlencode(query, doseq=True), ret.fragment))
+        return uri
+
     def filter(self, query, include=[], exclude=[]):
         exclude = list(set(exclude) | set(['page', 'count', 'sort', 'order', 'f']))
         if include:
